@@ -8,7 +8,8 @@ except:
     pass
 import numpy as np
 from pyoperators import MPI
-from pysimulators import Instrument, PointingMatrix, ProjectionInMemoryOperator
+from pysimulators import (Instrument, PointingMatrix,
+                          ProjectionInMemoryOperator, Map, Tod)
 from scipy.constants import c, pi
 from .calibration import QubicCalibration
 from .utils import _rotateuv, _compress_mask, _uncompress_mask
@@ -82,13 +83,13 @@ class QubicInstrument(Instrument):
     def _init_detectors(self, removed):
         class Detector(np.recarray):
             pass
-        dtype = [('center', [('x', float), ('y', float)]),
-                 ('corner', [('x', float), ('y', float)], 4),
+        dtype = [('center', float, 2),
+                 ('vertex', float, (4, 2)),
                  ('index', int),
                  ('quadrant', np.int8),
                  ('masked', bool),
                  ('removed', bool)]
-        shape, center, corner, removed_, index, quadrant = \
+        shape, center, vertex, removed_, index, quadrant = \
             self.calibration.get('detarray')
         if removed is not None:
             if isinstance(removed, str):
@@ -96,10 +97,8 @@ class QubicInstrument(Instrument):
             removed_ |= removed
         removed = removed_
         detector = Detector(shape, dtype=dtype)
-        detector.center.x = center[..., 0]
-        detector.center.y = center[..., 1]
-        detector.corner.x = corner[..., 0]
-        detector.corner.y = corner[..., 1]
+        detector.center = center
+        detector.vertex = vertex
         detector.masked = False
         detector.removed = removed
         detector.index = index
@@ -111,10 +110,9 @@ class QubicInstrument(Instrument):
             pass
         shape, center = self.calibration.get('hornarray')
         n = shape[0] * shape[1]
-        dtype = [('center', [('x', float), ('y', float)])]
+        dtype = [('center', float, 2)]
         horn = Horn(n, dtype=dtype)
-        horn.center.x = center[..., 0].ravel()
-        horn.center.y = center[..., 1].ravel()
+        horn.center = center.reshape((-1, 2))
         horn.spacing = abs(center[0, 0, 0] - center[0, 1, 0])
         self.horn = horn
 
@@ -182,10 +180,10 @@ class QubicInstrument(Instrument):
 
         """
         a = mp.gca()
-        corner = self.pack(self.detector.corner).view(float).reshape(
+        vertex = self.pack(self.detector.vertex).view(float).reshape(
             (-1, 4, 2))
-        for c in corner:
-            a.add_patch(mp.Polygon(c, closed=True, fill=False, **keywords))
+        for v in vertex:
+            a.add_patch(mp.Polygon(v, closed=True, fill=False, **keywords))
         if autoscale:
             mp.autoscale()
         mp.show()
@@ -204,7 +202,7 @@ class QubicInstrument(Instrument):
 
         """
         matrix = _peak_pointing_matrix(self, kmax, pointing)
-        return ProjectionInMemoryOperator(matrix)
+        return ProjectionInMemoryOperator(matrix, classin=Map, classout=Tod)
 
 
 def _peak_angles(q, kmax):
@@ -216,8 +214,8 @@ def _peak_angles(q, kmax):
     center = q.pack(q.detector.center)
     lmbda = c / q.optics.nu
     dx = q.horn.spacing
-    detvec = np.vstack([-center.x,
-                        -center.y,
+    detvec = np.vstack([-center[..., 0],
+                        -center[..., 1],
                         np.zeros(ndetector) + q.optics.focal_length]).T
     detvec.T[...] /= np.sqrt(np.sum(detvec**2, axis=1))
 
